==> aria2_0.9.0.orig.tar.gz: aria2-0.9.0/src/HttpDownloadCommand.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "HttpDownloadCommand.h"
#include "DlRetryEx.h"
#include "HttpRequestCommand.h"
#include "Util.h"
#include "ChunkedEncoding.h"
#include "message.h"
#include <sys/time.h>
#include <sys/types.h>
#include <unistd.h>
#include <algorithm>

using namespace std;

HttpDownloadCommand::HttpDownloadCommand(int cuid, const RequestHandle req,
					 DownloadEngine* e,
					 const SocketHandle& socket)
  :DownloadCommand(cuid, req, e, socket)
{
  ChunkedEncoding* ce = new ChunkedEncoding();
  transferEncodings["chunked"] = ce;
}

HttpDownloadCommand::~HttpDownloadCommand() {
  for(map<string, TransferEncoding*>::iterator itr = transferEncodings.begin(); itr != transferEncodings.end(); itr++) {
    delete((*itr).second);
  }
}

TransferEncoding* HttpDownloadCommand::getTransferEncoding(const string& name) {
  return transferEncodings[name];
}

bool HttpDownloadCommand::prepareForNextSegment(const Segment& currentSegment) {
  if(e->segmentMan->finished()) {
    return true;
  } else {
    if(req->isKeepAlive()) {
      Command* command = new HttpRequestCommand(cuid, req, e, socket);
      e->commands.push_back(command);
      return true;
    } else {
      return DownloadCommand::prepareForNextSegment(currentSegment);
    }
  }
}

==> aria2_0.11.0.orig.tar.gz: aria2-0.11.0/src/HttpDownloadCommand.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "HttpDownloadCommand.h"
#include "HttpRequestCommand.h"
#include "Util.h"
#include "message.h"

HttpDownloadCommand::HttpDownloadCommand(int cuid,
					 const RequestHandle req,
					 RequestGroup* requestGroup,
					 DownloadEngine* e,
					 const SocketHandle& socket)
  :DownloadCommand(cuid, req, requestGroup, e, socket) {}

HttpDownloadCommand::~HttpDownloadCommand() {}

bool HttpDownloadCommand::prepareForNextSegment() {
  if(!_requestGroup->getSegmentMan()->finished()) {
    if(req->isKeepAlive()) {
      Command* command = new HttpRequestCommand(cuid, req, _requestGroup, e, socket);
      e->commands.push_back(command);
      return true;
    } else {
      return DownloadCommand::prepareForNextSegment();
    }
  } else {
    return DownloadCommand::prepareForNextSegment();
  }
}
